==> calligra_2.9.7.orig.tar.xz: calligra-2.9.7/libs/flake/commands/KoEventActionRemoveCommand.h <==
/* This file is part of the KDE project
 * Copyright (C) 2008 Thorsten Zachmann <zachmann@kde.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef KOEVENTACTIONREMOVECOMMAND_H
#define KOEVENTACTIONREMOVECOMMAND_H

#include <kundo2command.h>
#include "flake_export.h"

class KoShape;
class KoEventAction;
class KoEventActionRemoveCommandPrivate;

/// API docs go here
class FLAKE_EXPORT KoEventActionRemoveCommand : public KUndo2Command
{
public:
    KoEventActionRemoveCommand(KoShape *shape, KoEventAction *eventAction, KUndo2Command *parent = 0);
    virtual ~KoEventActionRemoveCommand();

    /// redo the command
    void redo();
    /// revert the actions done in redo
    void undo();

private:
    KoEventActionRemoveCommandPrivate * const d;
};

#endif /* KOEVENTACTIONREMOVECOMMAND_H */

==> calligra_3.2.1+dfsg.orig.tar.xz: calligra-3.2.1/libs/flake/commands/KoEventActionRemoveCommand.h <==
/* This file is part of the KDE project
 * Copyright (C) 2008 Thorsten Zachmann <zachmann@kde.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef KOEVENTACTIONREMOVECOMMAND_H
#define KOEVENTACTIONREMOVECOMMAND_H

#include <kundo2command.h>
#include "flake_export.h"

class KoShape;
class KoEventAction;
class KoEventActionRemoveCommandPrivate;

/// API docs go here
class FLAKE_EXPORT KoEventActionRemoveCommand : public KUndo2Command
{
public:
    KoEventActionRemoveCommand(KoShape *shape, KoEventAction *eventAction, KUndo2Command *parent = 0);
    ~KoEventActionRemoveCommand() override;

    /// redo the command
    void redo() override;
    /// revert the actions done in redo
    void undo() override;

private:
    KoEventActionRemoveCommandPrivate * const d;
};

#endif /* KOEVENTACTIONREMOVECOMMAND_H */
